@@ -41,29 +41,29 @@ class NNextClient:
         - For gRPC: :class:`~nnext.grpc.PointsStub` and :class:`~nnext.grpc.CollectionsStub`
 
     Args:
-        host: Host name of NNext service. Default: `localhost`
+        host: Host name of NNext service. Default: `api.nnext.io`
         port: Port of the REST API interface. Default: 6040
         grpc_port: Port of the gRPC interface. Default: 6041
         prefer_grpc: If `true` - use gPRC interface whenever possible in custom methods.
-        https: If `true` - use HTTPS(SSL) protocol. Default: `false`
-        api_key: API key for authentication in NNext Cloud. Default: `None`
+        api_key: API key for authentication in NNext Cloud.
         **kwargs: Additional arguments passed directly into REST client initialization
     """
 
     def __init__(self,
-                 host="localhost",
+                 api_key,
+                 host="api.nnext.io",
                  port=6040,
+                 version="v0.0.1",
                  grpc_port=6041,
-                 prefer_grpc=True,
-                 https=None,
-                 api_key=None,
+                 prefer_grpc=False,
                  **kwargs):
         self._prefer_grpc = prefer_grpc
         self._grpc_port = grpc_port
         self._host = host
         self._port = port
+        self._version = version
 
-        self._https = https
+        self._https = True
         self._api_key = api_key
 
         http2 = kwargs.pop("http2", False)
@@ -71,7 +71,7 @@ class NNextClient:
         self._rest_headers = kwargs.pop("headers", {})
         if api_key is not None:
             if self._https is False:
-                warnings.warn("Api key is used with unsecure connection.")
+                warnings.warn("API key is used with unsecure connection.")
             if self._https is None:
                 self._https = True
 
@@ -80,7 +80,7 @@ class NNextClient:
             self._rest_headers['api-key'] = api_key
             self._grpc_headers['api-key'] = api_key
 
-        self.rest_uri = f"http{'s' if self._https else ''}://{host}:{port}"
+        self.rest_uri = f"https://{host}}"
         self._rest_args = {
             "headers": self._rest_headers,
             "http2": http2,
@@ -94,7 +94,6 @@ class NNextClient:
         self._grpc_collections_client: Optional[grpc.CollectionsStub] = None
         self._event_loop = None
         if prefer_grpc:
-            print("Connecting to NNext GRPC")
             asyncio.set_event_loop(self.event_loop)
             self._init_grpc_points_client(self._grpc_headers)
             self._init_grpc_collections_client(self._grpc_headers)
